import logoIcon from "../assets/images/logo.png";
import settingIcon from "../assets/images/icon-settings.png";
import reviewListingIcon from "../assets/images/icon-review-listing.png";
import instructionIcon from "../assets/images/icon-instruction.png";
import emailIcon from "../assets/images/icon-email.png";
import { Icon } from "@shopify/polaris";
import { MenuIcon, XIcon } from '@shopify/polaris-icons';
import { Link, useLocation } from "@remix-run/react";
import { useState, useEffect } from "react";

const generateTitle = (pathname) => {
    switch (pathname) {
        case '/app/upgrade':
            return 'Upgrade';
        case '/app/settings':
            return 'Settings';
        case '/app/review_listing':
            return 'Review Listing';
        case '/app/instruction':
            return 'Instruction';
        case '/app/support':
            return 'Support';
        case '/app/privacy_policy':
            return 'Privacy Policy';
        default:
            return 'Dashboard';
    }
};
export default function Header() {
    const location = useLocation();
    const pageTitle = generateTitle(location.pathname);
    const [isOpen, setIsOpen] = useState(false);
    useEffect(() => {
        document.title = pageTitle;
    }, [pageTitle]);
    const handleToggle = () => {
        setIsOpen(!isOpen);
    };
    return (
        <header>
            <div className="vins-instruction-bar">
                <p>To customize the color schemes of the review section. Go to theme editor. <Link to="/app/instruction">Click here</Link> for detailed instruction.</p>
            </div>
            <div className="vins-header-wrapper">
                <div className="vins-logo-wrapper"><Link to="/app"><img src={logoIcon} alt="logo" title="Logo" /><span>Reviews</span></Link></div>
                <h2 className="vins-page-title">{pageTitle}</h2>
                <div className="vins-navigations-desktop">
                    <nav>
                        <ul className="vins-navigation-desktop-menu vins-unstylished-list">
                            <li><Link className='vins-menu-item vins-button' to="/app/upgrade">Upgrade</Link></li>
                            <li><Link className='vins-menu-item' to="/app/settings"><img className='vins-header-icons' src={settingIcon} alt="Settings Icon" title="Settings" /></Link></li>
                            <li><Link className='vins-menu-item' to="/app/review_listing"><img className='vins-header-icons' src={reviewListingIcon} alt="Review Listing Icon" title="Review Listing" /></Link></li>
                            <li><Link className='vins-menu-item' to="/app/instruction"><img className='vins-header-icons' src={instructionIcon} alt="Instruction Icon" title="Instruction" /></Link></li>
                            <li><Link className='vins-menu-item' to="/app/support"><img className='vins-header-icons' src={emailIcon} alt="Support Icon" title="Support" /></Link></li>
                        </ul>
                    </nav>
                </div>
                <div className="vins-navigations-mobile">
                    <div className="vins-hamburger">
                        <button onClick={handleToggle} title="Menu Open">
                            <Icon source={MenuIcon} />
                        </button>
                    </div>
                </div>
                {isOpen &&
                    <div className="vins-mobile-menu">
                        <button className="vins-hamburger vins-close-icon" onClick={handleToggle} title="Menu Close" ><Icon source={XIcon} /></button>
                        <nav>
                            <ul className="vins-navigation-mobile-menu vins-unstylished-list">
                                <li><Link className='vins-menu-item' to="/app/review_listing"><img className='vins-header-icons' src={reviewListingIcon} alt="Review Listing Icon" title="Review Listing" /><span>Review list</span></Link></li>
                                <li><Link className='vins-menu-item vins-button' to="/app/upgrade">Upgrade</Link></li>
                                <li><Link className='vins-menu-item' to="/app/settings"><img className='vins-header-icons' src={settingIcon} alt="Settings Icon" title="Settings" /><span>Settings</span></Link></li>
                                <li><Link className='vins-menu-item' to="/app/instruction"><img className='vins-header-icons' src={instructionIcon} alt="Instruction Icon" title="Instruction" /><span>Instructions</span></Link></li>
                                <li><Link className='vins-menu-item' to="/app/support"><img className='vins-header-icons' src={emailIcon} alt="Support Icon" title="Support" /><span>Support</span></Link></li>
                                <li><Link className='vins-menu-item' to="/app/privacy_policy"><span>Privacy Policy</span></Link></li>
                            </ul>
                        </nav>
                    </div>
                }
            </div>
        </header>
    )
}