import { PieChart, Pie, Cell } from 'recharts';
import { SkeletonThumbnail } from "@shopify/polaris";

export default function ScoreIndicator({ overallRating, isloading }) {
    const RADIAN = Math.PI / 180;
    const data = [
        { value: 20, color: '#FFD966' },
        { value: 20, color: '#FFC46F' },
        { value: 20, color: '#FFAFA4' },
        { value: 20, color: '#81CAFF' },
        { value: 20, color: '#8AE08A' },
    ];
    const cx = 96;
    const cy = 120;
    const iR = 60;
    const oR = 100;
    const value = parseFloat(overallRating.toString().replace(/\./g, '')) * 2;
    const needle = (value, data, cx, cy, iR, oR, color) => {
        let total = 0;
        data.forEach((v) => {
            total += v.value;
        });
        const ang = 180.0 * (1 - value / total);
        // const length = (iR + 2 * oR) / 3;
        const length = 55;
        const sin = Math.sin(-RADIAN * ang);
        const cos = Math.cos(-RADIAN * ang);
        const r = 4;
        const x0 = cx + 4;
        const y0 = cy + 4;
        const xba = x0 + r * sin;
        const yba = y0 - r * cos;
        const xbb = x0 - r * sin;
        const ybb = y0 + r * cos;
        const xp = x0 + length * cos;
        const yp = y0 + length * sin;

        return [
            <circle cx={x0} cy={y0} r={r} fill={color} stroke="none" />,
            <path d={`M${xba} ${yba}L${xbb} ${ybb} L${xp} ${yp} L${xba} ${yba}`} stroke="#none" fill={color} />,
        ];
    };
    return (
        <div className='vins-image-with-text-Icon'>
            <>
                { isloading &&
                    <SkeletonThumbnail size="large" />
                }
                { !isloading &&
                    <>
                        <PieChart width={203} height={130}>
                            <Pie
                                dataKey="value"
                                startAngle={180}
                                endAngle={0}
                                data={data}
                                cx={cx}
                                cy={cy}
                                innerRadius={iR}
                                outerRadius={oR}
                                fill="#8884d8"
                                stroke="none"
                            >
                                {data.map((entry, index) => (
                                    <Cell key={`cell-${index}`} fill={entry.color} />
                                ))}
                            </Pie>
                            {needle(value, data, cx, cy, iR, oR, '#8D9BA7')}
                        </PieChart>
                        <h4 className='vins-sub-heading'>{overallRating} ☆ </h4>
                        <p>Average rating</p>
                    </>
                }
            </>
        </div>
    );
}

