import { authenticate } from "../shopify.server";
import { Divider, SkeletonBodyText, SkeletonThumbnail } from "@shopify/polaris";
import { useEffect, useState } from "react";
import { Link, useFetcher, useLoaderData } from "@remix-run/react";
import DonutChart from "../components/donut_chart";
import ScoreIndicator from "../components/score_indicator";
import HorizantalBarchart from "../components/horizantal_bar_chart";
import totalReviewImage from '../assets/images/image-total-reviews.png';
import viewAllImage from '../assets/images/image-view-all-reviews.png';
import feautureListIcon from "../assets/images/icon-features-list.png";
import colorSchemeIcon from '../assets/images/icon-color-scheme.png';
import viewByProductIcon from '../assets/images/icon-view-products.png';
import viewByCustomerIcon from '../assets/images/icon-view-customers.png';
import filterByStarRating from '../assets/images/icon-filter-rating.png';
import highestRatingIcon from '../assets/images/icon-higher-rating.png';
import lowerRatingIcon from '../assets/images/icon-lower-rating.png';
import newestReviewIcon from '../assets/images/icon-latest-review.png';
import oldestReviewIcon from '../assets/images/icon-oldest-review.png';
import recentReviwsIcon from '../assets/images/icon-recent-reviews.png';
import shareIcon from '../assets/images/icon-share.png';
import filterByDateIcon from '../assets/images/icon-filter-by-date.png';
import { defaultReviewData, skeletonValues } from "./service";

export const loader = async ({ request }) => {
  const { admin } = await authenticate.admin(request);
  const response = await admin.graphql(
    `#graphql
      query { shop { id } }`,
  );
  const responseJson = await response.json();
  const storeID = responseJson.data.shop.id.split('/');
  return storeID[storeID.length - 1];
};


export const action = async ({ request }) => {
  const { admin } = await authenticate.admin(request);
  const formData = new URLSearchParams(await request.text());
  const productIds = formData.getAll('productId');
  const productsId = productIds[0].split(',');
  const updatedProductIds = [];
  for (let index = 0; index < productsId.length; index++) {
    const element = "gid://shopify/Product/" + productsId[index];
    updatedProductIds.push(element);
  }
  const query = `
    query GetProductTitles($ids: [ID!]!) {
      nodes(ids: $ids) {
        ... on Product {
          title
        }
      }
    }
  `;
  const response = await admin.graphql(query, {
    variables: { ids: updatedProductIds },
  });
  const responseJson = await response.json();
  return (responseJson.data.nodes);
};

function formatDate(dateTimeString) {
  const date = new Date(dateTimeString);
  return date.toISOString().split('T')[0];
}


function ReviewCard({ reviewerName, starRating, reviewContent, productTitle, reviewTitle, date }) {
  return (
    <div className="vins-review-card">
      <div className="vins-reviewer-profile">
        <svg version="1.1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 600 600" width="40" height="40" fill="#8D99B6" class="vins-anonymous-user-icon"><defs><clipPath id="circular-border-0.1046138034132238"><circle cx="300" cy="300" r="250"></circle></clipPath></defs><circle cx="300" cy="300" r="280" fill="#CCD2E1"></circle><circle cx="300" cy="230" r="100"></circle><circle cx="300" cy="550" r="190" clip-path="url(#circular-border-0.1046138034132238)"></circle></svg>
      </div>
      <div className="vins-review-content">
        <p>{reviewerName}</p>
        <p className="vins-review-product-title">{productTitle}</p>
        <p className="vins-start-rating " style={{ '--rating': starRating }} >☆☆☆☆☆</p>
        <p>{reviewTitle}</p>
        <p>{reviewContent}</p>
        <p className="vins-review-date">{date}</p>
      </div>
    </div>
  )
}



export default function Index() {
  const fetcher = useFetcher();
  const [totalReviewCount, setTotalReviewCount] = useState(defaultReviewData.totalReviewCount);
  const [overallRating, setOverallRating] = useState(defaultReviewData.overAllRating);
  const [reviewsCount, setReviewsCount] = useState(defaultReviewData.reviewCount);
  const [reviewsPercentage, setReviewsPercentage] = useState(defaultReviewData.reviewPercentage);
  const [isLoading, setIsLoading] = useState(defaultReviewData.isLoadingValue);
  const [reviewsData, setReviewsData] = useState([]);
  const [reviewProductTitle, setReviewProductTitle] = useState([]);
  const storeID = useLoaderData();

  const getStoreStatistics = () => {
    const myHeaders = new Headers();
    myHeaders.append("Content-Type", "application/x-www-form-urlencoded");

    const urlencoded = new URLSearchParams();
    urlencoded.append("storeId", storeID);
    urlencoded.append("call", "getStoreStatistics");

    const requestOptions = {
      method: "POST",
      headers: myHeaders,
      body: urlencoded,
      redirect: "follow"
    };
    fetch("https://shopifydev.vinsinfo.in/ShopifyReviewApp/admin_review_functions.php", requestOptions)
      .then((response) => response.json())
      .then((result) => {
        setOverallRating(result.averageRating);
        setTotalReviewCount(result.totalReviews);
        if (result.totalReviews > defaultReviewData.totalReviewMinimumCount) {
          const updateReviewCount = [], updateReviewPercentage = [];
          for (let index = 1; index < 6; index++) {
            updateReviewCount.push(result.ratingsBreakdown[index].count);
            updateReviewPercentage.push(result.ratingsBreakdown[index].percentage);
          }
          setReviewsPercentage(updateReviewPercentage);
          setReviewsCount(updateReviewCount);
        }
      })
      .catch((error) => console.error(error));
  }
  const fetchProductDetails = (productID, totalReviewCount) => {
    if (totalReviewCount == defaultReviewData.totalReviewCount) {
      setIsLoading(false);
    } else {
      fetcher.submit(
        {
          productId: productID,
        },
        {
          method: 'post',
        }
      );
    }
  };
  const getRecentReviews = () => {
    const myHeaders = new Headers();
    myHeaders.append("Content-Type", "application/x-www-form-urlencoded");

    const urlencoded = new URLSearchParams();
    urlencoded.append("storeId", storeID);
    urlencoded.append("call", "getReviewsByStoreId");
    urlencoded.append("limit", "3");
    urlencoded.append("date_sort", "1");
    urlencoded.append("sort_by_date_asc", "0");

    const requestOptions = {
      method: "POST",
      headers: myHeaders,
      body: urlencoded,
      redirect: "follow"
    };
    fetch("https://shopifydev.vinsinfo.in/ShopifyReviewApp/admin_review_functions.php", requestOptions)
      .then((response) => response.json())
      .then((result) => {
        const reviewDataUpdate = [];
        const productIds = []
        for (let index = 0; index < result.reviews.length; index++) {
          productIds.push(result.reviews[index].productId);
          const reviewData = { "date": formatDate(result.reviews[index].date), "Name": result.reviews[index].name, "starRating": result.reviews[index].starCount, "description": result.reviews[index].reviewText, "reviewTitle": result.reviews[index].reviewTitle };
          reviewDataUpdate.push(reviewData);
        }
        fetchProductDetails(productIds, result.total_reviews);
        setReviewsData(reviewDataUpdate);
      })
      .catch((error) => console.error(error));
  }
  useEffect(() => {
    getStoreStatistics();
    getRecentReviews();
  }, [])
  useEffect(() => {
    if (fetcher.data) {
      setReviewProductTitle(fetcher.data);
      setIsLoading(false);
    }
  }, [fetcher.data])

  return (
    <>
      <div className="vins-dashboard">
        <div className="vins-review-rating-container vins-common-padding">
          <div className="vins-review-rating">
            <DonutChart
              totalReviewCount={totalReviewCount}
              overallRating={overallRating}
              fiveStarCount={reviewsCount[4]}
              fourStarCount={reviewsCount[3]}
              threeStarCount={reviewsCount[2]}
              twoStarCount={reviewsCount[1]}
              oneStarCount={reviewsCount[0]}
              isLoading={isLoading}
            />
            <HorizantalBarchart
              fiveStarCount={reviewsCount[4]}
              fourStarCount={reviewsCount[3]}
              threeStarCount={reviewsCount[2]}
              twoStarCount={reviewsCount[1]}
              oneStarCount={reviewsCount[0]}
              fiveStarPercentage={reviewsPercentage[4]}
              fourStarPercentage={reviewsPercentage[3]}
              threeStarPercentage={reviewsPercentage[2]}
              twoStarPercentage={reviewsPercentage[1]}
              oneStarPercentage={reviewsPercentage[0]}
              isLoading={isLoading}
              totalReviewCount={totalReviewCount}
            />
          </div>
          <p>AVERAGE RATING AND BREAKDOWN</p>
        </div>
        <Divider borderColor="border" />
        <div className="vins-image-with-text-container vins-common-padding">
          <div className="vins-image-with-text-Icon">
            {isLoading &&
              <SkeletonThumbnail />
            }
            {!isLoading &&
              <>
                <img className='vins-icon' src={totalReviewImage} alt="Icon" title="Total reviews" />
                <h4 className="vins-sub-heading">{totalReviewCount}</h4>
                <p>Total Reviews Collected</p>
              </>
            }

          </div>
          <ScoreIndicator
            overallRating={overallRating}
            isloading={isLoading}
          />
          <div className="vins-image-with-text-Icon">
            {isLoading &&
              <SkeletonThumbnail />
            }
            {!isLoading &&
              <>
                <img className='vins-icon' src={viewAllImage} alt="Icon" title="View all reviews" />
                <Link to='/app/review_listing'>View all reviews</Link>
              </>
            }
          </div>
        </div>
        <Divider borderColor="border" />
        <div className="vins-review-features-container vins-common-padding">
          <div className="vins-dashboard-item-heading">
            <div className="vins-dashboard-item-heading-media">
              <img src={feautureListIcon} alt="Icon" title="Features list" />
            </div>
            <div className="vins-dashboard-item-heading-content">
              <h2 className="vins-sub-heading">VINSINFO STAR RATING FEATURES</h2>
              <p>Below are the features in our review app</p>
            </div>
          </div>
          <div className="vins-review-features-list">
            {isLoading && <SkeletonBodyText lines={skeletonValues.featureListLines} />}
            {!isLoading &&
              <>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={colorSchemeIcon} alt="Icon" title="Customize color scheme" /><span >Customize Color Schemes</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={viewByProductIcon} alt="Icon" title="View by Products" /><span >View by Products</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={viewByCustomerIcon} alt="Icon" title="View by Customer" /><span >View by Customer</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={filterByStarRating} alt="Icon" title="Filter by Star Rating" /><span >Filter by Star Rating</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={newestReviewIcon} alt="Icon" title="View by Latest Review" /><span >View by Latest Review</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={oldestReviewIcon} alt="Icon" title="View by Oldest Review" /><span>View by Oldest Review</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={highestRatingIcon} alt="Icon" title="View by Higher Rating" /><span >View by Higher Rating</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={lowerRatingIcon} alt="Icon" title="View by Lower Rating" /><span >View by Lower Rating</span></Link>
                </div>
                <div className="vins-review-features">
                  <Link to="/app/review_listing"><img className="featureIcon" src={filterByDateIcon} alt="Icon" title="Filter by Date" /><span >Filter by Date</span></Link>
                </div>
              </>
            }
          </div>
        </div>
        <Divider borderColor="border" />
        <div className="vine-recent-review vins-common-padding">
          <div className="vins-dashboard-item-heading">
            <div className="vins-dashboard-item-heading-media">
              <img src={recentReviwsIcon} alt="Icon" title="Recent Reviews" />
            </div>
            <div className="vins-dashboard-item-heading-content">
              <h2 className="vins-sub-heading">RECENT REVIEWS</h2>
              <p>Below are the recent reviews from our store</p>
            </div>
          </div>
          <div className="vins-recent-review-list">
            {isLoading && totalReviewCount == defaultReviewData.totalReviewCount &&
              <SkeletonBodyText />
            }
            {!isLoading && totalReviewCount == defaultReviewData.totalReviewCount &&
              <p className="vins-center">No Recent Reviews</p>
            }
            {totalReviewCount > 0 &&
              <>
                {reviewsData.map((review, index) => (
                  <div key={review.reviewTitle} className={index % 2 === 0 ? "vins-review-odd" : "vins-review-even"}>
                    {isLoading &&
                      <SkeletonBodyText />
                    }
                    {!isLoading &&
                      <>
                        <ReviewCard reviewContent={review.description} reviewTitle={review.reviewTitle} productTitle={reviewProductTitle[index].title} reviewerName={review.Name} starRating={review.starRating} date={review.date} />
                        <Link to='/app/review_listing'><img className="vins-share-icon" src={shareIcon} alt="Share Icon" title="Share" /></Link>
                      </>
                    }
                  </div>
                ))}
              </>
            }
          </div>
        </div>
      </div>
    </>
  );
}
