import { json } from "@remix-run/node";
import { Link, Outlet, useLoaderData, useRouteError } from "@remix-run/react";
import { boundary } from "@shopify/shopify-app-remix/server";
import { AppProvider } from "@shopify/shopify-app-remix/react";
import { NavMenu } from "@shopify/app-bridge-react";
import polarisStyles from "@shopify/polaris/build/esm/styles.css?url";
import { authenticate } from "../shopify.server";
import "../assets/css/base.css";
import Header from "../components/header";
import Footer from "../components/footer";
import { Divider } from "@shopify/polaris";

export const links = () => [{ rel: "stylesheet", href: polarisStyles }];

export const loader = async ({ request }) => {
  await authenticate.admin(request);

  return json({ apiKey: process.env.SHOPIFY_API_KEY || "" });
};

export default function App() {
  const { apiKey } = useLoaderData();
  return (
    <AppProvider isEmbeddedApp apiKey={apiKey}>
      <NavMenu>
        <Link to="/app" rel="home">Home</Link>
        <Link to="/app/review_listing">Review Listing</Link>
        <Link to="/app/upgrade">Upgrade</Link>
        <Link to="/app/settings">Settings</Link>
        <Link to="/app/instruction">Instruction</Link>
        <Link to="/app/support">Support</Link>
        <Link to="/app/privacy_policy">Privacy Policy</Link>
      </NavMenu>
      <Header />
      <Divider borderColor="border" />
      <Outlet />
      <Divider borderColor="border" />
      <Footer />
    </AppProvider>
  );
}

// Shopify needs Remix to catch some thrown responses, so that their headers are included in the response.
export function ErrorBoundary() {
  return boundary.error(useRouteError());
}

export const headers = (headersArgs) => {
  return boundary.headers(headersArgs);
};
